/*
  messagehandlerinterface.h

  This file is part of GammaRay, the Qt application inspection and
  manipulation tool.

  Copyright (C) 2010-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
  Author: Milian Wolff <milian.wolff@kdab.com>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef GAMMARAY_MESSAGEHANDLER_MESSAGEHANDLERINTERFACE_H
#define GAMMARAY_MESSAGEHANDLER_MESSAGEHANDLERINTERFACE_H

#include <QObject>

class QTime;

namespace GammaRay {

class MessageHandlerInterface : public QObject
{
  Q_OBJECT
  public:
    explicit MessageHandlerInterface(QObject *parent = 0);
    virtual ~MessageHandlerInterface();

  signals:
    void fatalMessageReceived(const QString &app, const QString &message,
                              const QTime &time, const QStringList &backtrace);
};

}

Q_DECLARE_INTERFACE(GammaRay::MessageHandlerInterface, "com.kdab.GammaRay.MessageHandler")

#endif // GAMMARAY_MESSAGEHANDLERINTERFACE_H
